@@ -182,6 +182,10 @@ impl SourceDimensions {
         let lhs_line_nums_width = format_line_num(lhs_max_line).len();
         let rhs_line_nums_width = format_line_num(rhs_max_line).len();
 
+        assert!(
+            terminal_width > SPACER.len(),
+            "Terminal total width should not overflow"
+        );
         let lhs_total_width = (terminal_width - SPACER.len()) / 2;
 
         let lhs_content_width = if lhs_line_nums_width < lhs_total_width {
@@ -432,7 +436,7 @@ pub(crate) fn print(
         let no_rhs_changes = hunk.novel_rhs.is_empty();
         let same_lines = aligned_lines.iter().all(|(l, r)| l == r);
 
-        let source_dims = SourceDimensions::new(display_options.display_width, aligned_lines);
+        let source_dims = SourceDimensions::new(display_options.terminal_width, aligned_lines);
         for (lhs_line_num, rhs_line_num) in aligned_lines {
             let lhs_line_novel = highlight_as_novel(
                 *lhs_line_num,
@@ -590,6 +594,7 @@ mod tests {
 
     use super::*;
     use crate::{
+        options::DEFAULT_TERMINAL_WIDTH,
         parse::guess_language::Language,
         syntax::{AtomKind, MatchKind, TokenKind},
     };
@@ -597,7 +602,7 @@ mod tests {
     #[test]
     fn test_width_calculations() {
         let line_nums = [(Some(1.into()), Some(10.into()))];
-        let source_dims = SourceDimensions::new(80, &line_nums);
+        let source_dims = SourceDimensions::new(DEFAULT_TERMINAL_WIDTH, &line_nums);
 
         assert_eq!(source_dims.lhs_line_nums_width, 2);
         assert_eq!(source_dims.rhs_line_nums_width, 3);
@@ -606,7 +611,7 @@ mod tests {
     #[test]
     fn test_format_missing_line_num() {
         let source_dims = SourceDimensions::new(
-            80,
+            DEFAULT_TERMINAL_WIDTH,
             &[
                 (Some(0.into()), Some(0.into())),
                 (Some(1.into()), Some(1.into())),
@@ -619,7 +624,7 @@ mod tests {
         );
         assert_eq!(
             format_missing_line_num(0.into(), &source_dims, Side::Left, false),
-            ". ".to_string()
+            ". ".to_owned()
         );
     }
 
@@ -639,7 +644,7 @@ mod tests {
         );
         assert_eq!(
             format_missing_line_num(1.into(), &source_dims, Side::Left, false),
-            "  ".to_string()
+            "  ".to_owned()
         );
     }
 
@@ -650,7 +655,7 @@ mod tests {
             "foo.py",
             None,
             &FileFormat::SupportedLanguage(Language::Python),
-            &["print(123)\n".to_string()],
+            &["print(123)\n".to_owned()],
             Side::Right,
             &DisplayOptions::default(),
         );
