@@ -289,9 +289,14 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_css() };
             TreeSitterConfig {
                 language,
-                atom_nodes: vec!["integer_value", "float_value", "color_value"]
-                    .into_iter()
-                    .collect(),
+                atom_nodes: vec![
+                    "integer_value",
+                    "float_value",
+                    "color_value",
+                    "string_value",
+                ]
+                .into_iter()
+                .collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")")],
                 highlight_query: ts::Query::new(
                     language,
@@ -1608,10 +1613,9 @@ fn syntax_from_cursor<'a>(
 
     if node.is_error() {
         *error_count += 1;
+    }
 
-        // Treat error nodes as atoms, even if they have children.
-        atom_from_cursor(arena, src, nl_pos, cursor, highlights, ignore_comments)
-    } else if config.atom_nodes.contains(node.kind()) {
+    if config.atom_nodes.contains(node.kind()) {
         // Treat nodes like string literals as atoms, regardless
         // of whether they have children.
         atom_from_cursor(arena, src, nl_pos, cursor, highlights, ignore_comments)
